@@ -1,19 +1,17 @@
 use std::collections::HashMap;
 use std::marker::PhantomData;
 
-use cqrs_es::{Aggregate, AggregateContext, AggregateError, EventEnvelope, EventStore};
 use crate::connection::Connection;
+use cqrs_es::{Aggregate, AggregateContext, AggregateError, EventEnvelope, EventStore};
 
 /// Storage engine using an Postgres backing. This is the only persistent store currently
 /// provided.
-pub struct PostgresStore<A: Aggregate + Send + Sync>
-{
+pub struct PostgresStore<A: Aggregate + Send + Sync> {
     conn: Connection,
     _phantom: PhantomData<A>,
 }
 
-impl<A: Aggregate> PostgresStore<A>
-{
+impl<A: Aggregate> PostgresStore<A> {
     /// Creates a new `PostgresStore` from the provided database connection.
     pub fn new(conn: Connection) -> Self {
         PostgresStore {
@@ -23,15 +21,14 @@ impl<A: Aggregate> PostgresStore<A>
     }
 }
 
-
-static INSERT_EVENT: &str = "INSERT INTO events (aggregate_type, aggregate_id, sequence, payload, metadata)
+static INSERT_EVENT: &str =
+    "INSERT INTO events (aggregate_type, aggregate_id, sequence, payload, metadata)
                                VALUES ($1, $2, $3, $4, $5)";
 static SELECT_EVENTS: &str = "SELECT aggregate_type, aggregate_id, sequence, payload, metadata
                                 FROM events
                                 WHERE aggregate_type = $1 AND aggregate_id = $2 ORDER BY sequence";
 
-impl<A: Aggregate> EventStore<A, PostgresStoreAggregateContext<A>> for PostgresStore<A>
-{
+impl<A: Aggregate> EventStore<A, PostgresStoreAggregateContext<A>> for PostgresStore<A> {
     fn load(&self, aggregate_id: &str) -> Vec<EventEnvelope<A>> {
         let agg_type = A::aggregate_type();
         let id = aggregate_id.to_string();
@@ -54,7 +51,9 @@ impl<A: Aggregate> EventStore<A, PostgresStoreAggregateContext<A>> for PostgresS
                     result.push(event);
                 }
             }
-            Err(e) => { println!("{:?}", e); }
+            Err(e) => {
+                println!("{:?}", e);
+            }
         }
         result
     }
@@ -66,7 +65,7 @@ impl<A: Aggregate> EventStore<A, PostgresStoreAggregateContext<A>> for PostgresS
             current_sequence = envelope.sequence;
             let event = envelope.payload;
             aggregate.apply(&event);
-        };
+        }
         PostgresStoreAggregateContext {
             aggregate_id: aggregate_id.to_string(),
             aggregate,
@@ -74,13 +73,18 @@ impl<A: Aggregate> EventStore<A, PostgresStoreAggregateContext<A>> for PostgresS
         }
     }
 
-    fn commit(&self, events: Vec<A::Event>, context: PostgresStoreAggregateContext<A>, metadata: HashMap<String, String>) -> Result<Vec<EventEnvelope<A>>, AggregateError> {
+    fn commit(
+        &self,
+        events: Vec<A::Event>,
+        context: PostgresStoreAggregateContext<A>,
+        metadata: HashMap<String, String>,
+    ) -> Result<Vec<EventEnvelope<A>>, AggregateError> {
         let aggregate_id = context.aggregate_id.as_str();
         let current_sequence = context.current_sequence;
         let wrapped_events = self.wrap_events(aggregate_id, current_sequence, events, metadata);
         let mut conn = self.conn.conn();
         let trans = match conn.transaction() {
-            Ok(t) => { t }
+            Ok(t) => t,
             Err(err) => {
                 return Err(AggregateError::TechnicalError(err.to_string()));
             }
@@ -92,24 +96,35 @@ impl<A: Aggregate> EventStore<A, PostgresStoreAggregateContext<A>> for PostgresS
             let payload = match serde_json::to_string(&event.payload) {
                 Ok(payload) => payload,
                 Err(err) => {
-                    panic!("bad payload found in events table for aggregate id {} with error: {}", &id, err);
+                    panic!(
+                        "bad payload found in events table for aggregate id {} with error: {}",
+                        &id, err
+                    );
                 }
             };
             let metadata = match serde_json::to_string(&event.metadata) {
                 Ok(metadata) => metadata,
                 Err(err) => {
-                    panic!("bad metadata found in events table for aggregate id {} with error: {}", &id, err);
+                    panic!(
+                        "bad metadata found in events table for aggregate id {} with error: {}",
+                        &id, err
+                    );
                 }
             };
             let mut conn = self.conn.conn();
-            match conn.execute(INSERT_EVENT, &[&agg_type, &id, &sequence, &payload, &metadata]) {
+            match conn.execute(
+                INSERT_EVENT,
+                &[&agg_type, &id, &sequence, &payload, &metadata],
+            ) {
                 Ok(_) => {}
                 Err(err) => {
                     match err.code() {
                         None => {}
                         Some(state) => {
                             if state.code() == "23505" {
-                                return Err(AggregateError::TechnicalError("optimistic lock error".to_string()));
+                                return Err(AggregateError::TechnicalError(
+                                    "optimistic lock error".to_string(),
+                                ));
                             }
                         }
                     }
@@ -124,10 +139,8 @@ impl<A: Aggregate> EventStore<A, PostgresStoreAggregateContext<A>> for PostgresS
     }
 }
 
-
 /// Holds context for a pure event store implementation for MemStore
-pub struct PostgresStoreAggregateContext<A: Aggregate>
-{
+pub struct PostgresStoreAggregateContext<A: Aggregate> {
     /// The aggregate ID of the aggregate instance that has been loaded.
     pub aggregate_id: String,
     /// The current state of the aggregate instance.
@@ -136,10 +149,8 @@ pub struct PostgresStoreAggregateContext<A: Aggregate>
     pub current_sequence: usize,
 }
 
-
-impl<A: Aggregate> AggregateContext<A> for PostgresStoreAggregateContext<A>
-{
+impl<A: Aggregate> AggregateContext<A> for PostgresStoreAggregateContext<A> {
     fn aggregate(&self) -> &A {
         &self.aggregate
     }
-}
\ No newline at end of file
+}
